//
//  QueriesTableViewController.swift
//  Busca Pios
//
//  Created by Santiago Pavón on 18/12/14.
//  Copyright (c) 2014 UPM. All rights reserved.
//

import UIKit

class QueriesTableViewController: UITableViewController {

    
    // Fichero donde salvo las consultas
    private let SAVED_FILENAME = "queries.plist"
    
    // Las queries a mostrar en la tabla.
    var queries: [String]!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false
        
        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        self.navigationItem.leftBarButtonItem = self.editButtonItem()
        
        loadQueries()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    // MARK: - Table view data source
    
    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return queries.count
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Query Cell", forIndexPath: indexPath) as! UITableViewCell
        
        cell.textLabel?.text = queries[indexPath.row]
        
        return cell
    }
    
    
    override func tableView(tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return "Selecciona una Consulta"
    }
    
    
    override func tableView(tableView: UITableView, titleForFooterInSection section: Int) -> String? {
        return "IWEB 2014/2015"
    }
    
    
    /*
    // Override to support conditional editing of the table view.
    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
    // Return NO if you do not want the specified item to be editable.
    return true
    }
    */
    
    // Override to support editing the table view.
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            
            queries.removeAtIndex(indexPath.row)
            
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
            
            saveQueries()
            
        } else if editingStyle == .Insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }
    }
    
    // Override to support rearranging the table view.
    override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {
        
        let aux = queries[fromIndexPath.row]
        
        queries.removeAtIndex(fromIndexPath.row)
        queries.insert(aux, atIndex: toIndexPath.row)
        
        saveQueries()
    }
    
    // Override to support conditional rearranging of the table view.
    override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        return true
    }
    
    
    // MARK: Table View Delegate
    
    override func tableView(tableView: UITableView, titleForDeleteConfirmationButtonForRowAtIndexPath indexPath: NSIndexPath) -> String! {
        return "ñam ñam"
    }
    
    // MARK: - Navigation
    
    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        
        if segue.identifier == "Show Query" {
            
            if let ttvc = segue.destinationViewController as? TweetsTableViewController {
                
                if let row = tableView.indexPathForCell(sender as!UITableViewCell)?.row {
                    
                    ttvc.query = queries[row]
                }
            }
            
        } else if segue.identifier == "Add Query" {
            
            queries.insert("", atIndex: 0)
            
            let ip = NSIndexPath(forRow: 0, inSection: 0)
            
            tableView.insertRowsAtIndexPaths([ip], withRowAnimation: UITableViewRowAnimation.Right)
            
            tableView.selectRowAtIndexPath(ip, animated: true, scrollPosition: .Top)
            
            /*
            tableView.scrollToRowAtIndexPath(ip, atScrollPosition: UITableViewScrollPosition.Top, animated: true)
            */
            
            if let qevc = segue.destinationViewController as? QueryEditorViewController {
                
                qevc.query = ""
            }
            
        } else if segue.identifier == "Edit Query" {
            
            if let qevc = segue.destinationViewController as? QueryEditorViewController {
                
                if let ip = tableView.indexPathForCell(sender as! UITableViewCell) {
                    
                    tableView.selectRowAtIndexPath(ip, animated: true, scrollPosition: .Top)
                    
                    qevc.query = queries[ip.row]
                }
            }
        }
    }
    
    
    @IBAction func queryWasEdited(segue: UIStoryboardSegue) {
        
        if let qevc = segue.sourceViewController as? QueryEditorViewController {
            
            if let ip = tableView.indexPathForSelectedRow() {
                
                queries[ip.row] = qevc.query
                
                tableView.reloadRowsAtIndexPaths([ip], withRowAnimation: .Automatic)
                
                saveQueries()
            }
            
        }
    }
    
    // MARK: Persistencia
    
    private func getSavedQueriesPath() -> String {
        let path = NSSearchPathForDirectoriesInDomains(.DocumentDirectory,
            .UserDomainMask, true)[0] as! String
        
        return path.stringByAppendingPathComponent(SAVED_FILENAME)
    }
    
    
    private func loadQueries() {
        let path = getSavedQueriesPath()
        if let queries = NSArray(contentsOfFile: path) as? [String] {
            self.queries = queries
        } else {
            queries = ["Bachata","Tango","Merengue","Kizomba","Bolero",
                "Chachacha","Milonga","Vals"]
        }
    }
    
    private func saveQueries() {
        let path = getSavedQueriesPath()
        (queries as NSArray).writeToFile(path, atomically: true)
    }
}
